%define pypi_name pyglet

Name:       python-%{pypi_name}
Version:    1.5.27
Release:    %mkrel 1
Summary:    A cross-platform windowing and multimedia library for Python
Group:      Development/Python
License:    BSD
URL:        https://pypi.org/project/pyglet/

# The upstream tarball includes some non-free files in the examples and tests,
# and a patented texture compression algorithm.
# Run the following (in rpmbuild/SOURCES) to generate the distributed tarball
# (the subcommand outputs a version number like 1.5.16):
# $ bash pyglet-get-tarball.sh $(grep Version python-pyglet.spec|cut -c10-)
# See the script for details.
Source0: %{pypi_name}-%{version}-repacked.tar.gz
Source1: pyglet-get-tarball.sh

# Use importlib instead of imp
Patch0: python-pyglet-imp.patch

# Note that unbundling pypng removes "PNGImageDecoder", which is normally
# available for advanced use cases. Instead of:
#     img = image.load(fname, decoder=PNGImageDecoder) # don't use!
# It is enough to let Pyglet choose an appropriate decoder with:
#     img = image.load(fname)
# Pyglet docs even discourage hard-coding the decoder "unless your application
# has to work around specific deficiences in an operating system decoder":
#   https://pyglet.readthedocs.io/en/latest/programming_guide/image.html?highlight=PILImageDecoder#loading-an-image
# If you do find an issue with the default decoder on Fedora, file a bug.

BuildArch: noarch

BuildRequires: pyproject-rpm-macros
BuildRequires: pkgconfig(python3)
BuildRequires: python3-setuptools

%description
This library provides an object-oriented programming interface for developing
games and other visually-rich applications with Python.
pyglet has virtually no external dependencies. For most applications and game
requirements, pyglet needs nothing else besides Python, simplifying
distribution and installation. It also handles multiple windows and
fully aware of multi-monitor setups.

pyglet might be seen as an alternative to PyGame.

%package -n python3-%{pypi_name}
Summary: A cross-platform windowing and multimedia library for Python 3
Group: Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires: python3-pillow

# The libraries are imported dynamically using ctypes, so rpm can't find them.
Requires: libmesagl
Requires: libx11
Requires: fontconfig

%description -n python3-%{pypi_name}
This library provides an object-oriented programming interface for developing
games and other visually-rich applications with Python 3.
pyglet has virtually no external dependencies. For most applications and game
requirements, pyglet needs nothing else besides Python, simplifying
distribution and installation. It also handles multiple windows and
fully aware of multi-monitor setups.

pyglet might be seen as an alternative to PyGame.



%prep
%setup -q -n %{pypi_name}-%{version}

# Remove the bundled pypng library (python-pillow provides the same functionality)
rm pyglet/image/codecs/png.py
rm pyglet/extlibs/png.py

# Get rid of hashbang lines. This is a library, it has no executable scripts.
# Also remove Windows newlines
find . -name '*.py' | xargs sed --in-place -e's|#!/usr/bin/\(env \)\?python||;s/\r//'

%build
%pyproject_wheel

%generate_buildrequires
%pyproject_buildrequires

%install
%pyproject_install
%pyproject_save_files pyglet

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.md
%doc RELEASE_NOTES
%doc NOTICE



%changelog
* Sun Jan 07 2024 papoteur <papoteur> 1.5.27-1.mga9
+ Revision: 2028572
-new version 1.5.27, fix a crash (mga#32696)

* Wed Mar 23 2022 umeabot <umeabot> 1.5.16-3.mga9
+ Revision: 1823044
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.5.16-2.mga9
+ Revision: 1779226
- Rebuild for python-3.10

* Sat May 01 2021 daviddavid <daviddavid> 1.5.16-1.mga9
+ Revision: 1720664
- new version: 1.5.16

* Sun Apr 04 2021 joequant <joequant> 1.5.15-1.mga9
+ Revision: 1713284
- update to 1.5.15 / python 3.9

* Sat Nov 28 2020 guillomovitch <guillomovitch> 1.5.11-1.mga8
+ Revision: 1649874
- nex version 1.5.11

* Mon Sep 14 2020 guillomovitch <guillomovitch> 1.5.7-1.mga8
+ Revision: 1626471
- new version 1.5.7

* Tue Feb 18 2020 umeabot <umeabot> 1.4.6-2.mga8
+ Revision: 1538116
- Mageia 8 Mass Rebuild

* Wed Nov 13 2019 daviddavid <daviddavid> 1.4.6-1.mga8
+ Revision: 1459854
- new version: 1.4.6

* Thu Oct 10 2019 daviddavid <daviddavid> 1.3.2-2.mga8
+ Revision: 1450911
- rebuild for python3.8
- drop python2 support

* Sat Apr 20 2019 wally <wally> 1.3.2-1.mga7
+ Revision: 1393759
- new version 1.3.2

* Wed Jan 09 2019 shlomif <shlomif> 1.2.4-5.mga7
+ Revision: 1353911
- Rebuild for python3 3.7

* Thu Sep 20 2018 umeabot <umeabot> 1.2.4-4.mga7
+ Revision: 1289781
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1.2.4-3.mga7
+ Revision: 1135568
- Rebuild for python 3.6

* Sat Feb 20 2016 umeabot <umeabot> 1.2.4-2.mga6
+ Revision: 972471
- Mageia 6 Mass Rebuild

* Sun Nov 08 2015 philippem <philippem> 1.2.4-1.mga6
+ Revision: 898815
- update to 1.2.4

* Sun Nov 01 2015 philippem <philippem> 1.2-1.mga6
+ Revision: 897153
- update to 1.2

* Sat Oct 10 2015 tv <tv> 1.2-0.alpha1.5.mga6
+ Revision: 888954
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 1.2-0.alpha1.4.mga5
+ Revision: 746022
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2-0.alpha1.3.mga5
+ Revision: 729458
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2-0.alpha1.2.mga5
+ Revision: 688256
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.2-0.alpha1.1.mga5
+ Revision: 628946
- Rebuild for new Python

* Fri Nov 22 2013 philippem <philippem> 1.2-0.alpha1.0.mga4
+ Revision: 552350
- imported package python-pyglet

